Class: Fastlane::Actions::DependencyManagerOutdatedAction
- Inherits:
-
Action
- Object
- Action
- Fastlane::Actions::DependencyManagerOutdatedAction
- Defined in:
- lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb
Class Method Summary collapse
- .authors ⇒ Object
- .available_options ⇒ Object
- .description ⇒ Object
- .details ⇒ Object
- .is_supported?(platform) ⇒ Boolean
- .return_value ⇒ Object
- .run(params) ⇒ Object
Class Method Details
.authors ⇒ Object
15 16 17 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 15 def self. ["matsuda"] end |
.available_options ⇒ Object
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 28 def self. [ FastlaneCore::ConfigItem.new(key: :project_directory, env_name: "DEPENDENCY_MANAGER_PROJECT_DIRECTORY", description: "The path to the root of the project directory", optional: true), # slack FastlaneCore::ConfigItem.new(key: :slack_url, short_option: "-i", env_name: "DEPENDENCY_MANAGER_SLACK_URL", sensitive: true, description: "Create an Incoming WebHook for your Slack group to post results there", optional: true, verify_block: proc do |value| if !value.to_s.empty? && !value.start_with?("https://") UI.user_error!("Invalid URL, must start with https://") end end), FastlaneCore::ConfigItem.new(key: :slack_channel, short_option: "-e", env_name: "DEPENDENCY_MANAGER_SLACK_CHANNEL", description: "#channel or @username", optional: true), FastlaneCore::ConfigItem.new(key: :slack_username, env_name: "DEPENDENCY_MANAGER_SLACK_USERNAME", description: "Overrides the webhook's username property if slack_use_webhook_configured_username_and_icon is false", default_value: "fastlane", is_string: true, optional: true), FastlaneCore::ConfigItem.new(key: :slack_icon_url, env_name: "DEPENDENCY_MANAGER_SLACK_ICON_URL", description: "Overrides the webhook's image property if slack_use_webhook_configured_username_and_icon is false", default_value: "https://s3-eu-west-1.amazonaws.com/fastlane.tools/fastlane.png", is_string: true, optional: true), FastlaneCore::ConfigItem.new(key: :skip_slack, env_name: "DEPENDENCY_MANAGER_SKIP_SLACK", description: "Don't publish to slack, even when an URL is given", is_string: false, default_value: false), ] end |
.description ⇒ Object
11 12 13 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 11 def self.description "Fastlane plugin to check project's outdated dependencies" end |
.details ⇒ Object
23 24 25 26 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 23 def self.details # Optional: "Check outdated outdated CocoaPods and Carthage dependencies in project and notify to slack them" end |
.is_supported?(platform) ⇒ Boolean
72 73 74 75 76 77 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 72 def self.is_supported?(platform) # Adjust this if your plugin only works for a particular platform (iOS vs. Android, for example) # See: https://docs.fastlane.tools/advanced/#control-configuration-by-lane-and-by-platform # [:ios].include?(platform) end |
.return_value ⇒ Object
19 20 21 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 19 def self.return_value # If your method provides a return value, you can describe here what it does end |
.run(params) ⇒ Object
7 8 9 |
# File 'lib/fastlane/plugin/dependency_manager_outdated/actions/dependency_manager_outdated_action.rb', line 7 def self.run(params) UI.("The dependency_manager_outdated plugin is working!") end |